| Title: | Words and Gestures to Words and Sentences Score Conversion |
|---|---|
| Description: | Convert MacArthur-Bates Communicative Development Inventory Words and Gestures scores to would-be scores on Words and Sentences, based on modeling from the Stanford Wordbank <https://wordbank.stanford.edu/>. See Day et al. (2025) <doi:10.1111/desc.70036>. |
| Authors: | Trevor K.M. Day [cre, aut] (ORCID: <https://orcid.org/0000-0003-2911-8312>) |
| Maintainer: | Trevor K.M. Day <[email protected]> |
| License: | GPL (>= 3) |
| Version: | 0.2.0 |
| Built: | 2026-05-12 06:46:50 UTC |
| Source: | https://github.com/trevorkmday/cdiwg2ws |
Predict category scores
cat_models_strippedcat_models_stripped
An object of many linear models.
Linear models predicting WS category scores from WG score and age. The embedded data have been stripped from the object.
Frank, M. C., Braginsky, M., Yurovsky, D., & Marchman, V. A. (2017). Wordbank: An open repository for developmental vocabulary data. Journal of Child Language, 44(3), 677-694. doi:10.1017/S0305000916000209
Predict Connecting Words scores (no age)
cw_noage_strippedcw_noage_stripped
Linear model
A linear model predicting Connecting Words scores from other scores (no age). The embedded data have been stripped from the object.
Frank, M. C., Braginsky, M., Yurovsky, D., & Marchman, V. A. (2017). Wordbank: An open repository for developmental vocabulary data. Journal of Child Language, 44(3), 677-694. doi:10.1017/S0305000916000209
Predict Connecting Words scores
cw_strippedcw_stripped
Linear model
A linear model predicting Connecting Words scores from other scores and age. The embedded data have been stripped from the objects.
Frank, M. C., Braginsky, M., Yurovsky, D., & Marchman, V. A. (2017). Wordbank: An open repository for developmental vocabulary data. Journal of Child Language, 44(3), 677-694. doi:10.1017/S0305000916000209
WG dictionary: items, categories
g_dictg_dict
A data frame with 396 rows and 4 columns:
Name of category
Item label, e.g. "baa baa"
Unique ID
Type of item, only "word"
Frank, M. C., Braginsky, M., Yurovsky, D., & Marchman, V. A. (2017). Wordbank: An open repository for developmental vocabulary data. Journal of Child Language, 44(3), 677-694. doi:10.1017/S0305000916000209
WS dictionary: items, categories
s_dicts_dict
A data frame with 680 rows and 4 columns:
Name of category
Item label, e.g. "baa baa"
Unique ID
Type of item, only "word"
Frank, M. C., Braginsky, M., Yurovsky, D., & Marchman, V. A. (2017). Wordbank: An open repository for developmental vocabulary data. Journal of Child Language, 44(3), 677-694. doi:10.1017/S0305000916000209
Predict total score
total_WG_to_WS_noage_strippedtotal_WG_to_WS_noage_stripped
A linear model
A linear model predicting WS score from WG score (no age). The embedded data have been stripped from the object.
Frank, M. C., Braginsky, M., Yurovsky, D., & Marchman, V. A. (2017). Wordbank: An open repository for developmental vocabulary data. Journal of Child Language, 44(3), 677-694. doi:10.1017/S0305000916000209
Predict total score (w/ age)
total_WG_to_WS_strippedtotal_WG_to_WS_stripped
A linear model
A linear model predicting WS score from WG score and age. The embedded data have been stripped from the object.
Frank, M. C., Braginsky, M., Yurovsky, D., & Marchman, V. A. (2017). Wordbank: An open repository for developmental vocabulary data. Journal of Child Language, 44(3), 677-694. doi:10.1017/S0305000916000209
Take 22 WG scores and simulates WS scores for each one.
wg2ws_category_score(wg_table, age = NA, WG_total = NA, verbose = FALSE)wg2ws_category_score(wg_table, age = NA, WG_total = NA, verbose = FALSE)
wg_table |
A 22-row table with the columns |
age |
(Optional). Age in months. If unset, models not including age are used |
WG_total |
NA/numeric:
In the case of |
verbose |
T/F: Be verbose. |
This function predicts simulated WS scores for each category score independently. If an age is not supplied, models not using age are used (less accurate than including age).
New scores (data frame of 22 scores)
Day, T. K. M., Borovsky, A., Thal, D., & Elison, J. T. (2025). Modeling Longitudinal Trajectories of Word Production With the CDI. Developmental Science, 28(4), e70036. doi:10.1111/desc.70036
# Create list of words a child knows words <- c("smile", "old", "chicken (animal)", "breakfast", "snow", "uh oh", "please", "bad", "bicycle", "moon") # Create table wg_categories <- wg2ws_items(words) # Convert to WS score ws_categories <- wg2ws_category_score(wg_categories, age = 20)# Create list of words a child knows words <- c("smile", "old", "chicken (animal)", "breakfast", "snow", "uh oh", "please", "bad", "bicycle", "moon") # Create table wg_categories <- wg2ws_items(words) # Convert to WS score ws_categories <- wg2ws_category_score(wg_categories, age = 20)
Returns a model object to predict category score given category and age.
wg2ws_get_cat_function(the_category, age = TRUE, echo_only = FALSE)wg2ws_get_cat_function(the_category, age = TRUE, echo_only = FALSE)
the_category |
Which category to use, following Wordbank naming convention. Options: sounds, animals, vehicles, toys, food_drink, clothing, body_parts, household, furniture_rooms, outside, places, people, games_routines, action_words, descriptive_words, time_words, pronouns, question_words, locations, quantifiers, helping_verbs, connecting_words |
age |
T/F. If TRUE, return model that uses age as predictor. |
echo_only |
T/F. If FALSE, returns model as function; if TRUE echoes as human readable. |
This is mostly an internal function, but is exposed in case somebody needs
it. Returns a lm() object that has had the embedded data stripped, given
a category and whether to model age.
Function or NULL
Day, T. K. M., Borovsky, A., Thal, D., & Elison, J. T. (2025). Modeling Longitudinal Trajectories of Word Production With the CDI. Developmental Science, 28(4), e70036. doi:10.1111/desc.70036
wg2ws_get_cat_function("time_words", age = TRUE)wg2ws_get_cat_function("time_words", age = TRUE)
Given a list of items, create a table of category scores
wg2ws_items(items, error_on_missing = TRUE, in_inside = "either")wg2ws_items(items, error_on_missing = TRUE, in_inside = "either")
items |
List of WG items present for individual. |
error_on_missing |
If TRUE, check whether all items are actual WG
items. See helper function |
in_inside |
"In" and "inside" appear as two items on WG, but one ("inside/in") on WS. If "either," treat "inside/in" as endorsed if either appears. For "both", both must be endorsed. For "in" or "inside", treat "inside/in" as endorsed based solely on the presence of the indicated item. |
Requires a list that exactly matches items as labeled from Wordbank
(check g_dict). Converts to a table of category scores, ready for use
with wg2ws_category_score().
A data frame with 22 rows indicating item totals for all WS
categories. These values are not adjusted, and need to be adjusted with
wg2ws_category_score().
# Create list of words a child knows words <- c("smile", "old", "chicken (animal)", "breakfast", "snow", "uh oh", "please", "bad", "bicycle", "moon") # Create table categories <- wg2ws_items(words)# Create list of words a child knows words <- c("smile", "old", "chicken (animal)", "breakfast", "snow", "uh oh", "please", "bad", "bicycle", "moon") # Create table categories <- wg2ws_items(words)
List instrument items
wg2ws_list_items(instrument)wg2ws_list_items(instrument)
instrument |
"WG" or "WS" |
Simply list the items from each instrument for convenience.
List of items
wg2ws_list_items("WG") wg2ws_list_items("WS")wg2ws_list_items("WG") wg2ws_list_items("WS")
Summarize category table
wg2ws_summarize_cat(category_scores)wg2ws_summarize_cat(category_scores)
category_scores |
A 22x2 category result table |
Given a 22x2 category table, calculate total scores and lexical and syntax scores.
A three column data frame, with total score, lexical, and syntactic scores
Day, T. K. M., & Elison, J. T. (2021). A broadened estimate of syntactic and lexical ability from the MB-CDI. Journal of Child Language, 49(3), 615-632. doi:10.1017/S0305000921000283
words <- c("smile", "old", "chicken (animal)", "breakfast", "snow", "uh oh", "please", "bad", "bicycle", "moon") categories <- wg2ws_items(words) scores <- wg2ws_summarize_cat(categories)words <- c("smile", "old", "chicken (animal)", "breakfast", "snow", "uh oh", "please", "bad", "bicycle", "moon") categories <- wg2ws_items(words) scores <- wg2ws_summarize_cat(categories)
Calculate WS total score from WG score.
wg2ws_total_age(WG, age = NA)wg2ws_total_age(WG, age = NA)
WG |
Words and Gestures total score. |
age |
Age in months (optional). A different, more accurate model is used if age is supplied. |
Given a single number (WG total score) and optionally age, calculate a WG score.
Adjusted score, rounded to the nearest integer. Does not return values below 0 or greater than 680.
Day, T. K. M., Borovsky, A., Thal, D., & Elison, J. T. (2025). Modeling Longitudinal Trajectories of Word Production With the CDI. Developmental Science, 28(4), e70036. doi:10.1111/desc.70036
wg2ws_total_age(200) wg2ws_total_age(200, age = 21)wg2ws_total_age(200) wg2ws_total_age(200, age = 21)